pub struct InstallSummary {
pub handle: String,
pub target: String,
pub version: String,
pub written: Vec<String>,
pub skipped: bool,
pub unpinned: bool,
}Expand description
Outcome of an install.
Fields
handle: Stringtarget: Stringversion: Stringwritten: Vec<String>skipped: boolTrue when the artifact was already installed at this version (no writes).
unpinned: boolTrue when the manifest is not pinned to an immutable commit sha.